@@ -2,11 +2,11 @@ import asyncio
 import os
 import signal
 import traceback
-from typing import Any, Dict, List, Optional
+from typing import Optional
 
 import typer
-from rich import print
 
+from ...utils import ANSI
 from ._cli_hacks import _async_prompt, _patch_anyio_open_process
 from .agent import Agent
 from .utils import _load_agent_config
@@ -33,15 +33,15 @@ async def run_agent(
 
     Args:
         agent_path (`str`, *optional*):
-            Path to a local folder containing an `agent.json` and optionally a custom `PROMPT.md` file or a built-in agent stored in a Hugging Face dataset.
+            Path to a local folder containing an `agent.json` and optionally a custom `PROMPT.md` or `AGENTS.md` file or a built-in agent stored in a Hugging Face dataset.
 
     """
     _patch_anyio_open_process()  # Hacky way to prevent stdio connections to be stopped by Ctrl+C
 
     config, prompt = _load_agent_config(agent_path)
 
-    inputs: List[Dict[str, Any]] = config.get("inputs", [])
-    servers: List[Dict[str, Any]] = config.get("servers", [])
+    inputs = config.get("inputs", [])
+    servers = config.get("servers", [])
 
     abort_event = asyncio.Event()
     exit_event = asyncio.Event()
@@ -55,10 +55,10 @@ async def run_agent(
         if first_sigint:
             first_sigint = False
             abort_event.set()
-            print("\n[red]Interrupted. Press Ctrl+C again to quit.[/red]", flush=True)
+            print(ANSI.red("\nInterrupted. Press Ctrl+C again to quit."), flush=True)
             return
 
-        print("\n[red]Exiting...[/red]", flush=True)
+        print(ANSI.red("\nExiting..."), flush=True)
         exit_event.set()
 
     try:
@@ -71,70 +71,96 @@ async def run_agent(
             signal.signal(signal.SIGINT, lambda *_: _sigint_handler())
 
         # Handle inputs (i.e. env variables injection)
+        resolved_inputs: dict[str, str] = {}
+
         if len(inputs) > 0:
             print(
-                "[bold blue]Some initial inputs are required by the agent. "
-                "Please provide a value or leave empty to load from env.[/bold blue]"
+                ANSI.bold(
+                    ANSI.blue(
+                        "Some initial inputs are required by the agent. "
+                        "Please provide a value or leave empty to load from env."
+                    )
+                )
             )
             for input_item in inputs:
                 input_id = input_item["id"]
                 description = input_item["description"]
-                env_special_value = "${input:" + input_id + "}"  # Special value to indicate env variable injection
+                env_special_value = f"${{input:{input_id}}}"
 
-                # Check env variables that will use this input
-                input_vars = list(
-                    {
-                        key
-                        for server in servers
-                        for key, value in server.get("config", {}).get("env", {}).items()
-                        if value == env_special_value
-                    }
-                )
+                # Check if the input is used by any server or as an apiKey
+                input_usages = set()
+                for server in servers:
+                    # Check stdio's "env" and http/sse's "headers" mappings
+                    env_or_headers = server.get("env", {}) if server["type"] == "stdio" else server.get("headers", {})
+                    for key, value in env_or_headers.items():
+                        if env_special_value in value:
+                            input_usages.add(key)
 
-                if not input_vars:
-                    print(f"[yellow]Input {input_id} defined in config but not used by any server.[/yellow]")
+                raw_api_key = config.get("apiKey")
+                if isinstance(raw_api_key, str) and env_special_value in raw_api_key:
+                    input_usages.add("apiKey")
+
+                if not input_usages:
+                    print(
+                        ANSI.yellow(
+                            f"Input '{input_id}' defined in config but not used by any server or as an API key."
+                            " Skipping."
+                        )
+                    )
                     continue
 
                 # Prompt user for input
+                env_variable_key = input_id.replace("-", "_").upper()
                 print(
-                    f"[blue] • {input_id}[/blue]: {description}. (default: load from {', '.join(input_vars)}).",
+                    ANSI.blue(f" • {input_id}") + f": {description}. (default: load from {env_variable_key}).",
                     end=" ",
                 )
                 user_input = (await _async_prompt(exit_event=exit_event)).strip()
                 if exit_event.is_set():
                     return
 
-                # Inject user input (or env variable) into servers' env
+                # Fallback to environment variable when user left blank
+                final_value = user_input
+                if not final_value:
+                    final_value = os.getenv(env_variable_key, "")
+                    if final_value:
+                        print(ANSI.green(f"Value successfully loaded from '{env_variable_key}'"))
+                    else:
+                        print(
+                            ANSI.yellow(
+                                f"No value found for '{env_variable_key}' in environment variables. Continuing."
+                            )
+                        )
+                resolved_inputs[input_id] = final_value
+
+                # Inject resolved value (can be empty) into stdio's env or http/sse's headers
                 for server in servers:
-                    env = server.get("config", {}).get("env", {})
-                    for key, value in env.items():
-                        if value == env_special_value:
-                            if user_input:
-                                env[key] = user_input
-                            else:
-                                value_from_env = os.getenv(key, "")
-                                env[key] = value_from_env
-                                if value_from_env:
-                                    print(f"[green]Value successfully loaded from '{key}'[/green]")
-                                else:
-                                    print(
-                                        f"[yellow]No value found for '{key}' in environment variables. Continuing.[/yellow]"
-                                    )
+                    env_or_headers = server.get("env", {}) if server["type"] == "stdio" else server.get("headers", {})
+                    for key, value in env_or_headers.items():
+                        if env_special_value in value:
+                            env_or_headers[key] = env_or_headers[key].replace(env_special_value, final_value)
 
             print()
 
+        raw_api_key = config.get("apiKey")
+        if isinstance(raw_api_key, str):
+            substituted_api_key = raw_api_key
+            for input_id, val in resolved_inputs.items():
+                substituted_api_key = substituted_api_key.replace(f"${{input:{input_id}}}", val)
+            config["apiKey"] = substituted_api_key
         # Main agent loop
         async with Agent(
-            provider=config.get("provider"),
+            provider=config.get("provider"),  # type: ignore[arg-type]
             model=config.get("model"),
-            base_url=config.get("endpointUrl"),
-            servers=servers,
+            base_url=config.get("endpointUrl"),  # type: ignore[arg-type]
+            api_key=config.get("apiKey"),
+            servers=servers,  # type: ignore[arg-type]
             prompt=prompt,
         ) as agent:
             await agent.load_tools()
-            print(f"[bold blue]Agent loaded with {len(agent.available_tools)} tools:[/bold blue]")
+            print(ANSI.bold(ANSI.blue("Agent loaded with {} tools:".format(len(agent.available_tools)))))
             for t in agent.available_tools:
-                print(f"[blue] • {t.function.name}[/blue]")
+                print(ANSI.blue(f" • {t.function.name}"))
 
             while True:
                 abort_event.clear()
@@ -147,13 +173,13 @@ async def run_agent(
                     user_input = await _async_prompt(exit_event=exit_event)
                     first_sigint = True
                 except EOFError:
-                    print("\n[red]EOF received, exiting.[/red]", flush=True)
+                    print(ANSI.red("\nEOF received, exiting."), flush=True)
                     break
                 except KeyboardInterrupt:
                     if not first_sigint and abort_event.is_set():
                         continue
                     else:
-                        print("\n[red]Keyboard interrupt during input processing.[/red]", flush=True)
+                        print(ANSI.red("\nKeyboard interrupt during input processing."), flush=True)
                         break
 
                 try:
@@ -177,7 +203,7 @@ async def run_agent(
                                         print(f"{call.function.arguments}", end="")
                         else:
                             print(
-                                f"\n\n[green]Tool[{chunk.name}] {chunk.tool_call_id}\n{chunk.content}[/green]\n",
+                                ANSI.green(f"\n\nTool[{chunk.name}] {chunk.tool_call_id}\n{chunk.content}\n"),
                                 flush=True,
                             )
 
@@ -185,12 +211,12 @@ async def run_agent(
 
                 except Exception as e:
                     tb_str = traceback.format_exc()
-                    print(f"\n[bold red]Error during agent run: {e}\n{tb_str}[/bold red]", flush=True)
+                    print(ANSI.red(f"\nError during agent run: {e}\n{tb_str}"), flush=True)
                     first_sigint = True  # Allow graceful interrupt for the next command
 
     except Exception as e:
         tb_str = traceback.format_exc()
-        print(f"\n[bold red]An unexpected error occurred: {e}\n{tb_str}[/bold red]", flush=True)
+        print(ANSI.red(f"\nAn unexpected error occurred: {e}\n{tb_str}"), flush=True)
         raise e
 
     finally:
@@ -218,10 +244,10 @@ def run(
     try:
         asyncio.run(run_agent(path))
     except KeyboardInterrupt:
-        print("\n[red]Application terminated by KeyboardInterrupt.[/red]", flush=True)
+        print(ANSI.red("\nApplication terminated by KeyboardInterrupt."), flush=True)
         raise typer.Exit(code=130)
     except Exception as e:
-        print(f"\n[bold red]An unexpected error occurred: {e}[/bold red]", flush=True)
+        print(ANSI.red(f"\nAn unexpected error occurred: {e}"), flush=True)
         raise e
 
 
